<?php

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'Jitsi_Meet_WP_Admin' ) ) {
	class Jitsi_Meet_WP_Admin {
		/** @var null */
		private static $instance = null;

		/**
		 * Jitsi_Meet_WP_Admin constructor.
		 */
		public function __construct() {
            add_action('admin_menu', array( $this, 'jitsi_meet_wp_admin_menu_page' ));
            add_action( 'admin_init', [ $this, 'display_notices' ] );
            add_action( 'wp_ajax_jitsi_meet_wp_review_notice', [ $this, 'handle_review_notice' ] );
			add_action( 'wp_ajax_jitsi_meet_wp_affiliate_notice', [ $this, 'handle_affiliate_notice' ] );
            $this->jitsi_meet_wp_settings_files();
		}

        public function display_notices(){
            if ( ! get_option( 'webinar-and-video-conference-with-jitsi-meet_allow_tracking' ) ) {
				return;
			}

            //Review notice
			if ( 'off' != get_option( 'jitsi_meet_wp_review_notice_interval', 'on' ) && 'off' != get_transient( 'jitsi_meet_wp_review_notice_interval' ) ) {
                
                ob_start();
                jitsi_meet_wp()->get_template('admin/review-notice');
                $notice_html = ob_get_clean();

                jitsi_meet_wp()->add_notice( 'info jitsi-meet-wp-review-notice', $notice_html );
            }

			//Affiliate notice
			if ( 'off' == get_option( 'jitsi_meet_wp_review_notice_interval' )
			     && 'off' != get_option( 'jitsi_meet_wp_affiliate_notice_interval', 'on' )
			     && 'off' != get_transient( 'jitsi_meet_wp_affiliate_notice_interval' ) ) {

				ob_start();
				jitsi_meet_wp()->get_template( 'admin/affiliate-notice' );
				$notice_html = ob_get_clean();

				jitsi_meet_wp()->add_notice( 'info jitsi-meet-wp-affiliate-notice', $notice_html );
			}
        }

        public function handle_review_notice() {
			$value = ! empty( $_REQUEST['value'] ) ? sanitize_text_field( $_REQUEST['value'] ) : 7;

			if ( 'hide_notice' == $value ) {
				update_option( 'jitsi_meet_wp_review_notice_interval', 'off' );
			} else {
				set_transient( 'jitsi_meet_wp_review_notice_interval', 'off', $value * DAY_IN_SECONDS );
			}

			update_option( sanitize_key( 'jitsi_meet_wp_notices' ), [] );

		}

		public function handle_affiliate_notice() {
			$value = ! empty( $_REQUEST['value'] ) ? sanitize_text_field( $_REQUEST['value'] ) : 7;

			if ( 'hide_notice' == $value ) {
				update_option( 'jitsi_meet_wp_affiliate_notice_interval', 'off' );
			} else {
				set_transient( 'jitsi_meet_wp_affiliate_notice_interval', 'off', $value * DAY_IN_SECONDS );
			}

			update_option( sanitize_key( 'jitsi_meet_wp_notices' ), [] );

		}

        public function jitsi_meet_wp_settings_files()
        {
            require_once JITSI_MEET_WP_FILE_PATH . 'inc/admin/admin-settings.php';
			if(get_option('jitsi_meet_welcome_redirect', false) && get_option('jitsi_meet_welcome_redirect', false) != 'occured'){
                if(!isset($_GET['page']) || !($_GET['page'] == 'jitsi-meet-welcome')){
                    wp_redirect(admin_url('admin.php?page=jitsi-meet-welcome'));
                    die();
                }
				update_option('jitsi_meet_welcome_redirect', 'occured');
            } 
        }
        
        public function jitsi_meet_wp_admin_menu_page()
        {
            add_menu_page(
                'Jitsi Meet',
                esc_html__('Jitsi Meet', 'jitsi-meet-wp'),
                'manage_options',
                'jitsi-meet',
                array( $this, 'jitsi_meet_wp_manu_page_settings' ),
                'data:image/svg+xml;base64,' . base64_encode('<svg xmlns="http://www.w3.org/2000/svg" width="512" viewBox="0 0 49 28" fill="none"><path fill-rule="evenodd" clip-rule="evenodd" d="M34.4757 22.0614V17.2941L43.0323 23.4061C43.5361 23.7659 44.1987 23.814 44.7491 23.5307C45.2996 23.2474 45.6455 22.6803 45.6455 22.0612V5.53492C45.6455 4.91587 45.2996 4.34873 44.7491 4.06545C44.1987 3.78219 43.5361 3.8303 43.0323 4.19012L34.4757 10.3021V5.53504C34.4757 2.61741 31.8784 0.577148 29.0998 0.577148H8.62239C5.84387 0.577148 3.24658 2.61741 3.24658 5.53504V22.0614C3.24658 24.979 5.84387 27.0193 8.62239 27.0193H29.0998C31.8784 27.0193 34.4757 24.979 34.4757 22.0614ZM20.3316 18.1759C17.8232 16.8906 15.7668 14.8431 14.4904 12.3347L16.4404 10.3847C16.6886 10.1365 16.7596 9.79081 16.6621 9.48059C16.3341 8.48784 16.1568 7.42421 16.1568 6.31627C16.1568 5.82876 15.758 5.4299 15.2704 5.4299H12.1681C11.6807 5.4299 11.2818 5.82876 11.2818 6.31627C11.2818 14.6393 18.027 21.3845 26.35 21.3845C26.8375 21.3845 27.2364 20.9856 27.2364 20.4981V17.4047C27.2364 16.9172 26.8375 16.5183 26.35 16.5183C25.2509 16.5183 24.1784 16.341 23.1857 16.0131C22.8755 15.9068 22.5209 15.9865 22.2816 16.2258L20.3316 18.1759ZM25.8625 5.42103L26.4918 6.04149L20.8989 11.6345H24.5773V12.5209H19.2591V7.20264H20.1455V11.0051L25.8625 5.42103Z" fill="#407BFF"/></svg>'),
                40
            );

            add_submenu_page(
                'jitsi-meet',
                __('Webinar and Video Conference with Jitsi Meet', 'jitsi-meet-wp'),
                __('Documentation', 'jitsi-meet-wp'),
                'manage_options',
                'jitsi-meet',
                array( $this, 'jitsi_meet_wp_manu_page_settings' )
            );

			add_submenu_page(
                null,
                __('Jitsi Meet Welcome', 'jitsi-meet-wp'),
                null,
                'manage_options',
                'jitsi-meet-welcome',
                [ $this, 'jitsi_pro_manu_page_welcome_output' ]
            );

            add_submenu_page(
                'jitsi-meet',
                __('APP Settings', 'jitsi-meet-wp'),
                __('Settings', 'jitsi-meet-wp'),
                'manage_options',
                'jitsi-pro-settings',
                [ $this, 'jitsi_pro_manu_page_apis_output' ]
            );

            add_submenu_page(
                'jitsi-meet',
                null,
                __('Upgrade to Pro', 'jitsi-meet-wp'),
                'manage_options',
                'https://go.wppool.dev/qc5'
            );
        }

        public function jitsi_meet_wp_manu_page_settings()
        {
            ?>
			<div class="wrapv jitsi-admin-wrap jitsi-wrap">
				<?php settings_errors(); ?>
				<h3 class="title">
					<svg xmlns="http://www.w3.org/2000/svg" height="40" viewBox="0 0 49 28" fill="none">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M34.4757 22.0614V17.2941L43.0323 23.4061C43.5361 23.7659 44.1987 23.814 44.7491 23.5307C45.2996 23.2474 45.6455 22.6803 45.6455 22.0612V5.53492C45.6455 4.91587 45.2996 4.34873 44.7491 4.06545C44.1987 3.78219 43.5361 3.8303 43.0323 4.19012L34.4757 10.3021V5.53504C34.4757 2.61741 31.8784 0.577148 29.0998 0.577148H8.62239C5.84387 0.577148 3.24658 2.61741 3.24658 5.53504V22.0614C3.24658 24.979 5.84387 27.0193 8.62239 27.0193H29.0998C31.8784 27.0193 34.4757 24.979 34.4757 22.0614ZM20.3316 18.1759C17.8232 16.8906 15.7668 14.8431 14.4904 12.3347L16.4404 10.3847C16.6886 10.1365 16.7596 9.79081 16.6621 9.48059C16.3341 8.48784 16.1568 7.42421 16.1568 6.31627C16.1568 5.82876 15.758 5.4299 15.2704 5.4299H12.1681C11.6807 5.4299 11.2818 5.82876 11.2818 6.31627C11.2818 14.6393 18.027 21.3845 26.35 21.3845C26.8375 21.3845 27.2364 20.9856 27.2364 20.4981V17.4047C27.2364 16.9172 26.8375 16.5183 26.35 16.5183C25.2509 16.5183 24.1784 16.341 23.1857 16.0131C22.8755 15.9068 22.5209 15.9865 22.2816 16.2258L20.3316 18.1759ZM25.8625 5.42103L26.4918 6.04149L20.8989 11.6345H24.5773V12.5209H19.2591V7.20264H20.1455V11.0051L25.8625 5.42103Z" fill="#407BFF"/>
					</svg>
					<span><?php echo esc_html__('Webinar and Video Conference with Jitsi Meet', 'jitsi-meet-wp') ?></span>
				</h3>
				<div class="option-form-field-wrap">
					<?php $this->jitsi_pro_menu_page_tab_link('jitsi-meet'); ?>
					<div class="jitsi-setting-tabs">
						<div class="">
							<div class="jisti-admin-tab-links">
								<a class="active-jitsi-tab-link" href="#setup-jitsi-gutenberg">
                                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 254.24"><g id="Layer_2" data-name="Layer 2"><g id="Layer_1-2" data-name="Layer 1"><path d="M249.92,22.88c-.17,9.83-.09,19.66-.09,29.5v5.06L233.38,55c-4.37-.64-7.82-4.89-7.06-8.73.83-4.22,4.67-6,9.68-5,1.51.29,3.3-.85,5-1.34-1-1.31-1.73-3.19-3.05-3.83a12.08,12.08,0,0,0-16.29,6.23c-2.84,6.43.15,14.53,6.79,17.08a37.52,37.52,0,0,0,10.22,1.86c6.3.54,9.51,2.71,11.36,8,1.46,4.14.33,7.57-2.68,10.42-3.6,3.41-10.9,4.54-15,2.25-1.18-.66-2-2.11-2.76-3.33-3.34-5.37-6.14-11.14-10-16.12-7.28-9.5-7.39-19.34-2.3-29.49,2.13-4.26,5.5-7.89,8-12,.87-1.44.77-3.47,1.11-5.23-1.88.35-4.09.18-5.58,1.14-6.24,4-11.93,9-18.47,12.41-6.37,3.3-13.44,2.87-20.24-.27,2.88-4.43,6.15-5.13,11.06-3.94,8.1,2,18.39-4.26,21.61-12,1.49-3.58-.93-6.68-5.29-5.65-3.89.93-7.49,3.28-11.07,5.27a90.27,90.27,0,0,0-7.45,5.25c.39-7.48-.74-13.3-6.69-16.66-1.29-.73-3.43,0-5.19.09.63,1.49.86,3.43,1.95,4.41,4.82,4.33,5.39,10.14,1.14,14.84a9.75,9.75,0,0,1-14.63.1c-2.18-2.24-3.79-5-5.6-7.62C154,1.72,144.39-.47,132.1,5.79a9.07,9.07,0,0,1-7.27-.18c-11.13-5.93-20.94-4-28.54,6.15-2,2.66-3.61,5.63-5.77,8.14-4.39,5.11-11.61,5.42-15.9,1-4.06-4.23-3.28-10.14,1.57-14.92C77.3,4.84,77.4,2.7,78,1c-1.76.15-3.9-.29-5.23.55C67.29,5.05,66,10.76,65.63,18,62.71,16,60.52,14.45,58.2,13.1c-3.41-2-6.77-4.26-10.46-5.48C46,7,43,8,41.52,9.34c-.76.71.11,4,1.12,5.65,5.47,8.74,14,12.23,23.51,9.32,4.52-1.38,5.41,2.54,8.76,4.12C68.54,32,62.56,32,56.55,30.3c-8.07-2.23-14.65-7-20.53-12.82-1.19-1.18-3-2.39-4.56-2.42-2.85,0-3.12,2.9-.45,6C36.52,27.48,40.85,34.42,42.23,43A23,23,0,0,1,38.3,60C34.44,65.83,30.56,71.65,27,77.67c-2.76,4.68-7.09,6.52-13,4.8-5.68-1.66-9.11-5.89-8.68-10.71a11.36,11.36,0,0,1,9.92-10.32C18.9,61,22.66,61,26.14,60.05a13.14,13.14,0,0,0,8.49-17.18A12.08,12.08,0,0,0,18.2,36.08c-1.37.66-2,2.78-3,4.23,1.6.37,3.3,1.29,4.76,1,5.06-1,8.86.72,9.75,4.92.85,4-2.76,8.28-7.47,8.82L7.88,56.75c-.14-1.63-.4-3.37-.41-5.11,0-9.34.1-18.67-.16-28,0-1.51-1.77-3-2.72-4.45-.92,1.52-2.62,3-2.65,4.55-.22,12.33,0,24.66-.21,37C1.7,62.9.6,65.06,0,67.22v10c4.2,9.1,11.69,12.17,22,11.19-8.79,27.74-8.67,54.77,2.7,81.21s30.63,45.54,57.59,58.64c-11.63,2.42-19.32,8-23.58,18-.45,1.06-2.39,1.49-3.9,2.37-1.82-11.94-2.7-13-11.56-14.16-1.17-3.49-1.83-7.14-3.54-10.2-3.1-5.56-8.64-7.45-14.66-8.21C18.85,215.25,12.81,214,9.29,208c-2.88-4.92-2.52-9.72.36-14.65.79-1.34.29-3.44.39-5.19-1.75.74-4.16,1-5.15,2.32-5.18,6.93-4,17.83,2.24,24.35.92,1,1.94,1.81,3.24,3-6.2,4.93-8.86,11.44-8.63,19.16.13,4.16,1.67,4.95,5.22,3a41.18,41.18,0,0,1,6.84-2.78c4.66-1.55,8.61-4,9.81-9,.39-1.62-1-3.67-1.55-5.53-1.27,1.15-3.14,2.06-3.69,3.49-1.84,4.72-5.48,5.59-10.17,5.82.83-5.3,3.35-8.58,8.17-10,7.75-2.23,16.71,1.06,19.52,7.1,2,4.32.31,7.82-2.51,10.9s-6.3,3.9-10.43,2.29c-1.83-.71-4-.47-6.08-.66.52,2,1.05,4,1.71,6.45a112.26,112.26,0,0,0-11.34.13C5.7,248.37,4.29,250,2.82,251c1.46,1,2.9,2.73,4.37,2.75,18.48.18,37,.14,55.46.07,3.52,0,5.69-1.1,3.23-5.17a4,4,0,0,1,0-3.43c4.67-7.6,11.52-11.38,20.49-10.75a20.73,20.73,0,0,1,18,11.91c-.36.5-.73,1-1.1,1.49-1.65-1.28-3.58-2.31-4.91-3.87-7.1-8.36-20.56-7-25,2.76-.71,1.56.12,3.81.24,5.74,1.57-1,3.69-1.64,4.6-3.05,3.44-5.38,8.43-6.62,13.92-3-3.13,5.33-2.38,6.72,3.92,6.91,3.83.11,7.66.09,11.49,0s5.41-1.86,3.67-5.49c-1.92-4-4.14-7.86-6.28-11.87,3.19.49,6.8,1,10.39,1.63a3.3,3.3,0,0,1,2,1.19c2.94,4.56,5.72,9.22,8.69,13.75a3.86,3.86,0,0,0,2.63,1.74,4,4,0,0,0,2.49-1.87c2.89-4.41,5.59-9,8.52-13.34a4.75,4.75,0,0,1,2.78-1.61c3.23-.69,6.51-1.17,9.92-1.75-2.15,3.77-4.56,7.24-6.19,11.05-2,4.59-.49,6.46,4.55,6.53,5.66.08,11.34.26,17-.12,1.83-.13,3.55-1.91,5.31-2.93a56.2,56.2,0,0,0-5-2.85,9.89,9.89,0,0,0-3.06-.34c3.36-3.72,8.61-3.56,12,.25.75.86,1,2.17,1.87,2.91a30,30,0,0,0,4,2.63c.38-1.74,1.5-3.72,1-5.16-3.59-10.39-17.92-12.37-25.4-3.73a13.21,13.21,0,0,1-4.91,3.35c4.16-14.1,24.22-17.38,34.64-6.1,2.17,2.36,6.22,4.84,2.16,9.07-.15.15,1.62,3.15,2.74,3.34a58.52,58.52,0,0,0,9.47.27q22,0,44,0c1.67,0,3.42.27,5-.17,1.35-.37,2.48-1.57,3.7-2.41-1.19-1.06-2.32-2.92-3.6-3-4.46-.37-9-.14-14.19-.14,1-1.09,1.78-1.62,2-2.35a33.69,33.69,0,0,0,.92-4.29c-1.49-.05-3.33-.69-4.41,0-3.94,2.35-7.59,2.31-11.1-.53a9.85,9.85,0,0,1-3.81-10.21c1-4.48,4-7.08,8.44-8.24,9.57-2.5,16.1-.3,18.72,6.44a16.17,16.17,0,0,1,.48,3.14c-4.94-.4-8.76-1.39-10.12-6.66-.3-1.13-2.2-1.86-3.36-2.77-.74,1.48-2.28,3.09-2.06,4.42.78,4.82,4,7.83,8.51,9.58,3.22,1.24,6.28,3,9.57,3.92,1.34.38,3.12-.8,4.7-1.27v-2c-1.21-7.16-2.13-14.45-8.18-18.4,2.87-5.11,5.52-9.86,8.18-14.61v-6c-1.26-2.83-2.23-5.86-3.91-8.42-.74-1.11-2.94-1.26-4.48-1.84-.11,1.58-.85,3.48-.24,4.69,5.6,11,1.69,19.68-10.37,22.53-1.13.27-2.25.59-3.4.75-12.5,1.73-16.78,5.67-19.25,17.77-9.84,2.49-11.61,4.59-11.42,15-1.94-1.15-4.05-1.65-4.58-2.84-4.3-9.74-11.82-15.28-22.27-17.31,55.32-31.83,76.62-77.54,59-140.07,9.24.8,16.76-2.23,20.91-11.32v-56l-4.17-2.51C251.17,20.1,250,21.48,249.92,22.88Zm-205,224.85c-1.15.09-3.54-2-3.46-3,.11-1.47,1.78-3.71,3.08-3.94s3,1.54,5.78,3.14C47.78,245.8,46.41,247.62,44.91,247.73Zm167.92-7.08c1-.2,2.48,1.73,4.92,3.63-2.66,1.66-4.2,3.36-5.59,3.24-1.18-.1-3.25-2.53-3-3.5A5.53,5.53,0,0,1,212.83,240.65Zm4.3-171.58a102.83,102.83,0,0,1,17.29,41.57,59.06,59.06,0,0,1,.47,5.94c-10.06-1.7-10.08-1.7-12.11-10.68a95.86,95.86,0,0,0-20.9-42,13,13,0,0,1,.29-16.75c1.74-1.94,3.52-3.84,6.24-6.8C206.39,52.33,211.2,60.73,217.13,69.07Zm-9.38,59.87c3.75,3.63,6.88,6.23,9.4,9.32.92,1.12.78,3.51.44,5.17A87.9,87.9,0,0,1,199.84,182a10.25,10.25,0,0,1-5.72,3c-4.05.78-8.23,1-13.58,1.51C197.6,170.67,206.57,151.79,207.75,128.94Zm-72.4,69.65,65.43-64.53C200,167.59,167,198.24,135.35,198.59Zm73-74.77a24.22,24.22,0,0,1-1.08-4c-1.32-16.28-7.41-30.59-17.64-43.23-.31-.39-.57-.94-1-1.11-1.79-.73-3.63-1.34-5.45-2,.32,1.87,0,4.25,1,5.52,7,8.52,12.22,17.86,15,28.51,1,3.65,1.52,7.41,2.26,11.12l-1.18.79c-7.27-7.43-14.45-15-21.86-22.23-1.85-1.82-3.85-6.29-7-3s1.26,5.19,3.15,7.1c8.33,8.39,16.83,16.61,25.07,24.71L129,196.63,58.37,125.77c7.73-7.71,16.16-16,24.39-24.45,1.83-1.87,6.15-3.85,2.86-7.08-3-3-4.89,1.21-6.68,2.93-6.27,6-12.31,12.21-18.45,18.32-1.13,1.11-2.38,2.11-4.53,4,2.2-18.23,9.31-32.56,21.84-45.16C81.88,79,85.36,83.2,89.22,87.06c1.07,1.07,3.27,1,5,1.44-.25-1.73.08-3.91-.85-5.12C90,79,86.23,75,82.2,70.39c11.23-9.09,23.57-14.56,38.25-15.09-5.36,5.37-10.78,10.68-16,16.15-1.8,1.87-5.67,3.82-2.93,6.81,3,3.22,5-.8,6.71-2.56,6.65-6.72,13.08-13.65,20-20.93,7,7.07,13,13.23,19.13,19.37,1.05,1.07,2,2.48,3.25,3.06,1.43.66,3.21.56,4.84.79-.26-1.6,0-3.73-.87-4.73-4.63-5-9.59-9.73-14.41-14.57-1.12-1.13-2.15-2.37-3.23-3.55.21-.51.43-1,.64-1.52,6.25,1.8,12.59,3.31,18.7,5.49,4,1.43,7.65,4,11.63,5.7,1.81.76,4.06.5,6.11.7-1-1.81-1.51-4.32-3-5.32-10.76-7.09-22.74-10.87-35.53-12.13L133,47.81c2.6-3.21,5-6.4,7.69-9.34a4.49,4.49,0,0,1,3.46-1,83.35,83.35,0,0,1,34.93,13.91c2.51,1.71,2.6,10.38.3,13-5.36,6.17-10.89,12.19-16.06,18.5-1.08,1.32-1.93,4.48-1.19,5.34,2.35,2.73,4,0,5.49-1.7,5.34-6,10.55-12,15.88-18,3.48-3.9,11.62-3.76,15,.28a90.28,90.28,0,0,1,19.2,40.65c.53,2.71.47,4.88-2.51,6.75C212.63,117.79,211,120.76,208.36,123.82ZM73.74,70.07c-14.78,14.67-22.4,32.28-24,52.41-3.31-2.82-6.54-5.38-9.48-8.24-.71-.68-.8-2.4-.6-3.55A89.26,89.26,0,0,1,58.46,69.46C62.05,65.05,70,65.25,73.74,70.07ZM63.46,57.73c.33-1.54,2-3.7,3.33-3.88s3,1.75,5.7,3.6c-2.71,1.71-4.19,3.37-5.67,3.37C65.61,60.81,63.29,58.56,63.46,57.73ZM77.09,186.48c-6.11-.57-10.87-.87-15.58-1.54A6.43,6.43,0,0,1,58,182.56a88.71,88.71,0,0,1-18.45-40.87,4.36,4.36,0,0,1,.91-3.39c2.87-2.78,6-5.29,9.18-8.06C51.25,151.86,59.64,170.78,77.09,186.48Zm-20.42-51L119.4,198.7C94.39,202.48,53.72,162.06,56.67,135.52ZM186.53,56.8c0-1.41,1.8-2.83,3.59-5.31,1.77,2.48,3.68,4.06,3.41,5A5.55,5.55,0,0,1,189.87,60C188.87,60.15,186.54,58,186.53,56.8Zm-13-25.61c9.62,5.14,19.19,8.24,30,4L204,36.3c-2.94,3.34-5.31,7.83-9,9.68-3.4,1.7-9.16,2.17-12.24.37-11.9-6.93-24.17-12.42-37.79-14.79-4.8-.83-5.81-3.1-5.35-11A93.07,93.07,0,0,1,173.49,31.19Zm-36-21.6c7.08-4.13,16.39-.25,19.79,8.36-6.59-1.24-13.06-2.4-19.48-3.77A3.3,3.3,0,0,1,135.57,12C135.5,11.25,136.61,10.1,137.47,9.59Zm-15.3,23.78a78.63,78.63,0,0,1,3-13.52,4.18,4.18,0,0,1,3.39-2.26c1.37.14,3.37,1.37,3.76,2.57,1.39,4.22,2.21,8.63,2.78,11,.3,6.82-2,9.73-6.13,9.91C124.54,41.3,121.64,38.38,122.17,33.37ZM78.71,65.56c-3.71-3-3.71-12-.1-14.44a90.83,90.83,0,0,1,32.87-13.6c2.79-.58,5-.42,6.27,2.95,1.23,3.18,3.4,6,4.3,7.52C107.77,49,92.22,54.79,78.71,65.56ZM118.9,9.25c1.13.55,1.84,1.95,2.75,2.95-1,.79-1.8,2.08-2.87,2.3-6.27,1.3-12.59,2.35-19.38,3.57C104.34,9.15,111.85,5.84,118.9,9.25ZM85.19,30.46c9.6-4,19.8-6.51,29.76-9.63a17.49,17.49,0,0,1,3.36-.3,77.16,77.16,0,0,1-1.72,8.57,4,4,0,0,1-2.78,2.07A101.75,101.75,0,0,0,73.06,47.81c-2.5,1.76-10.65.11-12.67-2.2-2.51-2.88-5-5.81-7.42-8.74-.17-.21-.09-.62-.24-1.82C64.7,40.28,74.68,34.83,85.19,30.46ZM32.53,79.53a59.65,59.65,0,0,1,5.65-9.42C44.64,61.79,50,53.15,49,41.57c2.82,3.18,6.85,6,8.1,9.66,1.18,3.51.9,9.17-1.26,11.87C44.45,77.35,36.66,93,33.66,111a5.57,5.57,0,0,1-2.83,3.46c-2.49,1.21-5.27,1.84-8.75,3A94.35,94.35,0,0,1,32.53,79.53ZM23.78,124c4-1.83,8.2-3.77,12.48-4.28,3.75-.44,6.43,2.35,6.54,6.55.1,3.86-2.93,6.66-9,6.74-2.21-.94-6.23-2.4-10-4.35C21.44,127.5,21.48,125.1,23.78,124Zm16.28,61.41c-10.13-14.76-16.42-31-17.8-48.92,0-.3.21-.61.43-1.16,2.94,1,5.93,1.87,8.81,3a3.81,3.81,0,0,1,2.07,2.37c2.38,16.08,8.73,30.48,18.81,44.3-3.59.77-6.29,1.56-9,1.85A4.19,4.19,0,0,1,40.06,185.45Zm32.3,30.69c10.06-2.12,26.87,4.25,38.13,14.73C96.29,228,84,223.52,72.36,216.14Zm45.21,12.36c-3.66-2.76-7.2-5.74-11-8.26a64.79,64.79,0,0,0-40.74-10.75c-2.65.16-5.45-2.08-8.18-3.21l.45-1.91c7.67-1.92,15.41-1.11,23,.38,13.67,2.67,25.63,9,36.47,17.7C120.26,224.62,120.17,226.27,117.57,228.5ZM60.41,198a10.63,10.63,0,0,0-3,.29c-5.6,2.26-8.77-.57-11.79-6.25,5.44-.47,10.52-1.77,15.35-1.13a236.64,236.64,0,0,1,29.27,5.66c11.64,3,23,7,35.25,10.84v13.77c-2.38-1.8-4-3-5.68-4.3C102.35,203.33,82.82,196.13,60.41,198Zm68.13,46.36c-7.79-7-7.79-13.14,0-18.62C136.85,231.07,136.84,237.76,128.54,244.4Zm20.67-14.73a50.32,50.32,0,0,1,35.26-13.81A82,82,0,0,1,149.21,229.67Zm40.89-20.1c-17.6-1.06-33,4.88-46.37,16.18l-4,3.37c-.89-1.5-1.63-2.73-2.51-4.2,18.16-15.34,38.26-23.86,63.1-20.8C197.36,208,194.79,209.85,190.1,209.57Zm8.61-11.29c-22.62-2.56-42.57,4.52-60.39,18.28-1.8,1.4-3.62,2.77-6.69,5.1,0-5.57-.13-9.93.14-14.25,0-.72,1.73-1.64,2.8-1.94,9.87-2.71,19.91-4.85,29.61-8.06,13.54-4.48,27.12-7.77,41.49-6,1.8.22,3.57.62,5.71,1C208.8,199.15,204.39,198.93,198.71,198.28Zm32.51-41.61a169.24,169.24,0,0,1-10.49,23.57c-4.42,8.35-5.83,8.48-14.88,4.55,3.27-5.74,7-11.27,9.68-17.29,3-6.79,5.81-13.88,7.09-21.13,1-5.79,3.28-8.78,8.8-9.74a40.69,40.69,0,0,0,4.55-1.5C234.31,142.94,233.51,150.06,231.22,156.67Zm5.89-31.58c-4.86,6-9.77,7.67-15.17,7.85a6.71,6.71,0,0,1-6.64-7.16c.37-3.6,4.12-7,7.72-6.08C227.5,120.86,231.73,123,237.11,125.09Z"/><path d="M249.73,91.7c-1.84,1.24-4.37,1.4-6.38,2.45-1.51.79-2.67,2.23-4,3.38,1.62.73,3.18,1.8,4.87,2.09s3.47-.2,5.6-.38c0,13-.05,25.41.08,37.87,0,1.44,1.09,2.87,1.67,4.31l4.42-2.19v-46C254.57,90,252.66,89.73,249.73,91.7Z"/><path d="M250.82.33a60.75,60.75,0,0,0-12.43,0c-1.73.17-3.31,1.81-5,2.78,1.6,1,3.11,2.72,4.81,2.93a78.15,78.15,0,0,0,10.13.14L252,14.43l4-2.23v-9C254.28,2.2,252.63.52,250.82.33Z"/><path d="M234.34,183.76c.07.87,1.31,2.38,2,2.36,6.55-.14,13.1-.55,19.65-.88v-3c-6.67-.39-13.34-.84-20-1C235.42,181.19,234.27,182.92,234.34,183.76Z"/><path d="M238,176.38c.57,1.13,1.84,2.7,2.81,2.7,5.06,0,10.12-.52,15.18-.84v-3c-5.42-.47-10.83-1-16.26-1.28C239.16,173.93,237.79,175.93,238,176.38Z"/><path d="M241.69,168.89c-.26.59,1.25,2.82,1.88,2.78,4.15-.25,8.29-.91,12.43-1.43v-3c-3.77-.36-7.54-.92-11.31-.92C243.64,166.31,242.17,167.76,241.69,168.89Z"/><path d="M244.52,162.23c-.13.56,1.64,2.25,2.5,2.22a85.64,85.64,0,0,0,9-1.21v-3a72,72,0,0,0-9.09-.94C246,159.3,244.79,161.08,244.52,162.23Z"/><path d="M246.73,154.72c0,.9,1.41,2.54,2.2,2.54a44.32,44.32,0,0,0,7.07-1v-3a44.16,44.16,0,0,0-7.07-1C248.14,152.2,246.73,153.84,246.73,154.72Z"/><path d="M4.58,141.43c4.1,0,2.38-4,2.57-6.35.25-3.14.06-6.32.06-9.49V99c2.69.37,4.72,1.07,6.6.78,1.47-.23,2.75-1.68,4.11-2.58-1.11-1-2.07-2.38-3.38-3-2.22-1-4.82-1.25-6.95-2.38-4.52-2.4-5.8-1.79-5.87,3.52-.08,5,0,10,0,15,0,8.17-.12,16.34.08,24.5C1.83,137.28.07,141.47,4.58,141.43Z"/><path d="M4.64,186.3a48.81,48.81,0,0,0,7.46.11,55.53,55.53,0,0,0,8-.13c1.11-.17,2-1.68,3-2.59-1-.91-1.91-2.56-2.93-2.61a156.94,156.94,0,0,0-15.94,0c-.95,0-1.81,1.81-2.72,2.78C2.54,184.71,3.5,186.12,4.64,186.3Z"/><path d="M29.8,195.22c-2.23-.46-4.63-.13-7-.14s-4.72-.31-7,.12c-1.33.25-2.43,1.67-3.64,2.56,1.11,1,2.17,2.68,3.33,2.75a120.28,120.28,0,0,0,14.46,0c1.08-.06,2.06-1.6,3.09-2.45C32,197.05,31.05,195.48,29.8,195.22Z"/><path d="M4.46,179.19c1.88.45,3.94.12,5.92.12v0c1.82,0,3.74.35,5.43-.11,1.32-.35,2.37-1.71,3.53-2.62-1.05-1-2-2.78-3.18-2.88a69.2,69.2,0,0,0-11.87,0c-1,.08-1.87,1.78-2.8,2.74C2.47,177.45,3.32,178.92,4.46,179.19Z"/><path d="M32.16,200.92l-.7,1.28c-1.83,0-3.77-.38-5.45.12-1.46.44-2.63,1.88-3.93,2.88,1.35,1,2.57,2.34,4.06,2.77a14,14,0,0,0,5.45.11c2.86-.34,7.12,1.57,7.69-2.81C39.43,204.14,34.67,202.39,32.16,200.92Z"/><path d="M1.72,169.23c0,1,1.52,2.3,2.66,2.8s2.6.1,3.92.1v.1c1.16,0,2.5.37,3.43-.09A27.39,27.39,0,0,0,15.94,169c-1.39-.91-2.69-2.36-4.19-2.62a20,20,0,0,0-4.31-.25l5.6-4.24c-2-.93-4-2.53-6-2.58-1.81,0-3.66,1.63-5.5,2.55l5.44,4.3a24.23,24.23,0,0,0-2.58.3C3.28,166.64,1.72,168.25,1.72,169.23Z"/><path d="M35.36,212.8c1.93.85,3.86,2.39,5.78,2.38,2.13,0,4.25-1.45,6.37-2.26-.76-1.09-1.32-2.48-2.34-3.18-.84-.58-2.23-.33-3.35-.45-1.36.11-2.89-.16-3.94.42S36.18,211.73,35.36,212.8Z"/><path d="M16.7,188.88c.05,1.31-.39,3.32.26,3.77,1.21.85,3.06.8,4.59,1.11,1.74-.31,3.62-.2,4.84-1,.66-.45.22-2.52.28-3.86Z"/><path d="M6.16,158.86l4.72-4c-1.62-1-3.2-2.58-4.87-2.67-1.46-.08-3,1.57-4.52,2.45Z"/><path d="M12.05,205a4.44,4.44,0,0,0,2.71,2.63c.73.19,1.87-1.18,3.68-2.46-1.92-1.31-3-2.59-4.07-2.6C13.54,202.57,11.88,204.42,12.05,205Z"/><path d="M31,209.88c-1.13.3-2,1.65-2.95,2.55,1,.89,1.9,2.24,3.05,2.5.7.16,1.78-1.35,3.37-2.67C32.83,211.08,31.7,209.7,31,209.88Z"/><path d="M8.47,146.92c-2.25-1.06-3.47-2.12-4.57-2a3.31,3.31,0,0,0-2,2.66c.11.92,1.65,2.41,2.43,2.33C5.47,149.79,6.46,148.47,8.47,146.92Z"/><path d="M227.27,6c1.41,0,2.77-2,4.15-3-1.34-.93-2.63-2.56-4-2.66C222.61,0,217.79.19,213,.2c-4.64,0-9.3-.25-13.91.14-1.47.13-2.79,2-4.18,3,1.34.92,2.67,2.62,4,2.65C208.37,6.25,217.83,6.27,227.27,6Z"/><path d="M45.58,6.26c4.65,0,9.31.25,13.92-.14,1.51-.13,2.87-1.94,4.3-3C62.43,2.22,61.08.53,59.69.5,50.24.26,40.78.23,31.34.5c-1.46,0-2.86,1.92-4.28,3,1.53.94,3,2.56,4.6,2.69C36.27,6.5,40.94,6.27,45.58,6.26Z"/><path d="M9.83,72.24a7.7,7.7,0,0,0,7.66,7.61,7.45,7.45,0,0,0,7.76-7.4,7.73,7.73,0,0,0-7.56-8.2A7.93,7.93,0,0,0,9.83,72.24Z"/><path d="M238.88,79.84a7.75,7.75,0,0,0,7.94-7.36,8,8,0,0,0-7.68-8.24,8.11,8.11,0,0,0-8,7.47A7.87,7.87,0,0,0,238.88,79.84Z"/><path d="M2,9.67a31,31,0,0,0,2.9,4.82c1-1.44,2.76-2.87,2.8-4.34C7.8,6.66,9.46,6,12.4,6.14A40.61,40.61,0,0,0,20.8,6c1.25-.2,2.27-1.83,3.39-2.81C23.09,2.2,22.1.56,20.86.34,18.29-.1,15.6.21,13,.21v0c-1.82,0-3.65.09-5.46,0-4-.27-5.87,1.52-5.58,5.56C2,7.05,1.57,8.52,2,9.67Z"/><path d="M242.41,32.25c3.93.17,4.07-2.73,4.18-5.39.24-5.78-4.62-11.42-9.84-10.78-1.78.22-3.25,2.9-3.91,3.53C232.81,27.29,237,32,242.41,32.25Z"/><path d="M21.22,16.08c-5-.76-10.36,5.13-10.11,10.66.13,2.62.36,5.56,4.2,5.52,5.25,0,9.76-5,9.79-12.46C24.43,19.12,23,16.35,21.22,16.08Z"/><path d="M175,20.4a7,7,0,0,0,7.18-6.76,7.33,7.33,0,0,0-7.09-7.47,7.42,7.42,0,0,0-7.2,7.4A7,7,0,0,0,175,20.4Z"/><path d="M83.34,20.4a6.8,6.8,0,0,0,6.86-7,7.19,7.19,0,0,0-6.7-7.26A7.52,7.52,0,0,0,76,13.28,7.28,7.28,0,0,0,83.34,20.4Z"/><path d="M245.07,197.8c-1-.91-1.89-2.41-3-2.59a45.71,45.71,0,0,0-7.41-.13v0a50.57,50.57,0,0,0-7.89.13c-1,.17-1.8,1.85-2.69,2.85.91.8,1.78,2.24,2.73,2.29,5.1.23,10.23.26,15.33,0C243.16,200.35,244.1,198.71,245.07,197.8Z"/><path d="M231.63,207.79c1.31-.36,2.32-1.76,3.47-2.71-1.1-1-2.13-2.69-3.31-2.8a61.81,61.81,0,0,0-11.38.07c-1,.09-2.22,1.76-2.48,2.9-.15.63,1.37,2.17,2.36,2.41a30.43,30.43,0,0,0,5.91.42v-.17C228,207.91,230,208.27,231.63,207.79Z"/><path d="M213.76,209.37c-1.39.82-2.65,1.85-3.95,2.8,1.24,1,2.34,2.51,3.75,2.94a10.21,10.21,0,0,0,5.4-.06c1.17-.33,2-1.74,3-2.67-.94-1-1.73-2.22-2.87-2.83a2.72,2.72,0,0,0-2-.22C215.06,209.33,214.25,209.08,213.76,209.37Z"/><path d="M235.66,193.35c1.15,0,2.58.43,3.38-.11,1-.66,1.48-2.12,2.19-3.23-2.15-.69-4.28-1.85-6.45-1.92-1.59-.05-3.23,1.33-4.84,2.07.75,1.06,1.31,2.46,2.33,3.08C233.11,193.76,234.51,193.35,235.66,193.35Z"/><path d="M226.4,215c.92-1,2.31-1.8,2.59-2.92.19-.76-1.17-1.91-2.41-3.74-1.27,1.89-2.52,3-2.55,4.07C224,213.27,225.55,214.15,226.4,215Z"/><path d="M155.14,119.23c-4.09,5-9.78,5.92-15.64,6.56a14.71,14.71,0,0,0-11.62,7.63c-.66,1.16-.2,3-.26,4.48,1.48-.54,3.16-.81,4.41-1.68,2.55-1.77,4.87-3.87,7.29-5.83l1.47,1.32c0,3.14.74,6.53-.2,9.37s-3,6.23-5.55,7.37c-9,4.14-18.46-1.25-19.57-11.16a92.79,92.79,0,0,1,0-19.43c.72-7.17,5.77-11.66,12.38-12.32s10,1.82,13.2,9.12c.49,1.09,2.53,2.55,3.19,2.27,1.22-.51,3-2.53,2.69-3.32-1-3-2.12-6.51-4.34-8.61-10.29-9.8-29.53-4.65-32.51,9.18a69.09,69.09,0,0,0-.56,24.71c2.22,14.28,18.07,20.8,30.55,13.43,4.46-2.63,7.05-6.48,7.07-11.82a59.82,59.82,0,0,0,0-6c-.31-3,.67-4.68,3.68-6s5.38-3.72,7.74-6c.6-.56,0-2.35,0-3.57C157.39,119,155.64,118.61,155.14,119.23Z"/><path d="M191.46,70.15c.08,1.49-.43,3.47.34,4.4,8.32,10,14.16,21.18,16.24,34.2.16,1,2.13,2.22,3.42,2.45.62.11,1.61-1.86,2.17-2.56a69.24,69.24,0,0,0-17.89-37.86C195,70,192.92,70.33,191.46,70.15Z"/><path d="M46.55,111.21c1.15,0,3.11-1.58,3.27-2.69,1.93-12.92,7.88-23.83,16-33.81.81-1,.21-3.11.27-4.71-1.45.29-3.49.06-4.28.94a70.08,70.08,0,0,0-17.74,37.73C44.62,109.27,45.6,111.22,46.55,111.21Z"/></g></g></svg>
                                    <?php _e('Gutenberg', 'jitsi-meet-wp'); ?>
                                </a>
								<a href="#setup-jitsi-elementor">
                                    <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 27 27"><path fill-rule="evenodd" clip-rule="evenodd" d="M0 13.2084C0 20.4107 5.83624 26.2501 13.0347 26.2501C20.2332 26.2501 26.0695 20.4107 26.0695 13.2084C26.0695 6.00609 20.2332 0.166748 13.0347 0.166748C5.83624 0.166748 0 6.00609 0 13.2084ZM9.77554 7.77424H7.60342V18.6426H9.77554V7.77424ZM11.9477 7.77424H18.4641V9.94753H11.9477V7.77424ZM18.4641 12.1208H11.9477V14.2941H18.4641V12.1208ZM11.9477 16.4693H18.4641V18.6426H11.9477V16.4693Z" fill="currentColor" id="e-icon"></path></svg>  
                                    <?php _e('Elementor', 'jitsi-meet-wp'); ?>
                                </a>
								<a href="#setup-jitsi-shortcode">
                                <svg viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg"><path d="M0 3V96.8451H25.5649V88.0555H11.1478V11.7896H25.5649V3H0Z"/><path d="m41.425 96.845 27.441-93.845h-10.29l-27.441 93.845h10.29z"/><path d="M100 96.8451V3H74.4351V11.7896H88.8522V88.0555H74.4351V96.8451H100Z"/></svg>
                                    <?php _e('Shortcode', 'jitsi-meet-wp'); ?>
                                </a>
							</div>
							<div class="jisti-admin-box">
								<div id="setup-jitsi-gutenberg" class="jitsi-tab active-jitsi-tab">
									<div class="jitsi-video">
										<iframe width="1280" height="720" src="https://www.youtube.com/embed/747LSskWDac" frameborder="0"
											allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
											allowfullscreen></iframe>
									</div>
									<div class="text-docs">
										<h4><?php esc_html_e('How to set a conference room', 'jitsi-meet-wp'); ?></h4>
										<p><?php esc_html_e('Very simple and easy steps', 'jitsi-meet-wp'); ?></p>
										<ul>
											<li>
												<span
													class="text-docs-item-content"><?php esc_html_e('While you are on the post/page edit screen click on gutenberg plus icon to add a new gutenberg block', 'jitsi-meet-wp') ?></span>
												<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/step-1.png'; ?>"
													alt="<?php esc_attr_e('Add new gutenberg block on page', 'jitsi-meet-wp'); ?>" />
											</li>
											<li>
												<span
													class="text-docs-item-content"><?php esc_html_e('Add "Jitsi Meet" from "Embeds" category', 'jitsi-meet-wp') ?></span>
												<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/step-2.png'; ?>"
													alt="<?php esc_attr_e('Add Jitsi Meet from Embeds category', 'jitsi-meet-wp'); ?>" />
											</li>
											<li>
												<span
													class="text-docs-item-content"><?php esc_html_e('Set width and height and you are done', 'jitsi-meet-wp') ?></span>
												<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/step-3.png'; ?>"
													alt="<?php esc_attr_e('Jitsi Meet Settings', 'jitsi-meet-wp'); ?>" />
											</li>
										</ul>
									</div>
								</div>
                                <div id="setup-jitsi-elementor" class="jitsi-tab">
									<div class="text-docs">
										<h4><?php esc_html_e('How to set with elementor', 'jitsi-meet-wp'); ?></h4>
										<p><?php esc_html_e('Setup a video conference room with elementor', 'jitsi-meet-wp'); ?></p>
										<ul>
											<li>
												<span
													class="text-docs-item-content"><?php _e('While you are on elementor edit screen drag and drop <strong>Jitsi Meet</strong> element to your page', 'jitsi-meet-wp') ?></span>
												<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/el-step-1.jpg'; ?>"
													alt="<?php esc_attr_e('Add new jitsi meet element on page', 'jitsi-meet-wp'); ?>" />
											</li>
											<li>
												<span
													class="text-docs-item-content"><?php esc_html_e('Set name, width, height etc and you are done', 'jitsi-meet-wp') ?></span>
												<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/el-step-2.jpg'; ?>"
													alt="<?php esc_attr_e('Jitsi Meet Settings', 'jitsi-meet-wp'); ?>" />
											</li>
										</ul>
									</div>
								</div>
								<div id="setup-jitsi-shortcode" class="jitsi-tab">
									<div class="text-docs">
										<h4><?php esc_html_e('How to set with shortcode', 'jitsi-meet-wp'); ?></h4>
										<p><?php esc_html_e('Setup a video conference room with shortcode', 'jitsi-meet-wp'); ?></p>
										<p class="text-docs-item-content">
											<?php esc_html_e('Write down the shortcode below and set width, height and name of conference', 'jitsi-meet-wp') ?>
                                            <pre class="jitsi-pre"><code class="jitsi-click-copy">[jitsi-meet-wp name="Sample Meeting" width="1080" height="720"/]</code><span class="inline-copy-message"><?php _e('Click on shortcode to copy', 'jitsi-meet-wp'); ?></span>
                                            </pre>
										</p>
										<ul>
											<li><strong>name: </strong>A unique name to generate the url of the room</li>
											<li><strong>width: </strong>Width of the jitsi meet embeded</li>
											<li><strong>height: </strong>Height of the jitsi meet embeded</li>
										</ul>
										<img class="text-docs-item-img" src="<?php echo JITSI_MEET_WP_URL . '/docs/img/step-2.1.png'; ?>"
											alt="<?php esc_attr_e('Jitsi Meet Settings', 'jitsi-meet-wp'); ?>" />
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
        }

        public function jitsi_pro_menu_page_tab_link($link = 'apis')
        {
            $arroftab = array(
                'jitsi-meet'	=> sprintf('<svg size="20" color="#0376DA" viewBox="0 0 24 24" class="sc-htoDjs fgURlR"><g><path fill-rule="evenodd" d="M15 2h.5858a1 1 0 0 1 .7071.2929l3.4142 3.4142c.1875.1875.2929.4419.2929.7071V21c0 .5523-.4477 1-1 1H5c-.5523 0-1-.4477-1-1V3c0-.5523.4477-1 1-1h10zm-2 2v3c0 1.1046.8954 2 2 2h3v11H6V4h7zm5 3h-3V4h.1716L18 6.8284V7zm-9 9c-.5523 0-1 .4477-1 1s.4477 1 1 1h6c.5523 0 1-.4477 1-1s-.4477-1-1-1H9zm-1-2c0-.5523.4477-1 1-1h6c.5523 0 1 .4477 1 1s-.4477 1-1 1H9c-.5523 0-1-.4477-1-1zm1-4c-.5523 0-1 .4477-1 1s.4477 1 1 1h6c.5523 0 1-.4477 1-1s-.4477-1-1-1H9z" clip-rule="evenodd"></path></g></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('Documentation', 'jitsi-meet-wp'), __('How to embed', 'jitsi-meet-wp')),
                'apis' 		    => sprintf('<svg size="24" viewBox="0 0 24 24" class="sc-htoDjs brCwHT"><g><path fill-rule="evenodd" d="M9 12c-2.7614 0-5-2.2386-5-5s2.2386-5 5-5 5 2.2386 5 5c0 1.019-.3049 1.967-.8284 2.7574L20 16.5858c.3111.3111.3744.7763.1897 1.15a.9954.9954 0 0 1-.24.3855l-2.8284 2.8284c-.3905.3906-1.0237.3906-1.4142 0-.3905-.3905-.3905-1.0236 0-1.4142l2.2071-2.2071-1.5858-1.5858-1.0858 1.0858c-.3905.3906-1.0236.3906-1.4142 0-.3905-.3905-.3905-1.0237 0-1.4142l1.0858-1.0858-3.1568-3.1568C10.967 11.6951 10.0191 12 9 12zm0-2c1.6569 0 3-1.3431 3-3s-1.3431-3-3-3-3 1.3431-3 3 1.3431 3 3 3z" clip-rule="evenodd"></path></g></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('API Settings', 'jitsi-meet-wp'), __('Authenticate with JAAS', 'jitsi-meet-wp')),
                'admin' 	    => sprintf('<svg size="24" viewBox="0 0 24 24" class="sc-htoDjs brCwHT"><g><path fill-rule="evenodd" d="M20.5 17h-3.6762c-.1155-.7365-.2893-1.4027-.5254-2h3.6952A4.7212 4.7212 0 0 0 20 14.75c0-3.6983-.8752-4.75-4-4.75-.8127 0-1.4732.0711-2.0058.2415A4.9715 4.9715 0 0 0 14 10c0-1.3984-.574-2.6626-1.4993-3.57C12.538 4.5293 14.0904 3 16 3c1.933 0 3.5 1.567 3.5 3.5a3.4832 3.4832 0 0 1-.5913 1.9473C21.1785 9.3075 22 11.4084 22 14.75c0 1.5-.5 2.25-1.5 2.25zm-3-10.5c0 .8284-.6716 1.5-1.5 1.5s-1.5-.6716-1.5-1.5S15.1716 5 16 5s1.5.6716 1.5 1.5zM3.75 22C2.5833 22 2 21.1667 2 19.5c0-3.8103 1.0093-6.1687 3.8183-7.0754A3.9824 3.9824 0 0 1 5 10c0-2.2091 1.7909-4 4-4 2.2091 0 4 1.7909 4 4a3.982 3.982 0 0 1-.8184 2.4246C14.9907 13.3313 16 15.6897 16 19.5c0 1.6667-.5833 2.5-1.75 2.5H3.75zM11 10c0 1.1046-.8954 2-2 2s-2-.8954-2-2 .8954-2 2-2 2 .8954 2 2zm3 9.5c0 .2139-.0122.3804-.0272.5H4.0272C4.0122 19.8804 4 19.7139 4 19.5 4 15.2936 5.1303 14 9 14s5 1.2936 5 5.5z" clip-rule="evenodd"></path></g></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('Admin Settings', 'jitsi-meet-wp'), __('Username, email, avatar etc.', 'jitsi-meet-wp')),
                'config' 	    => sprintf('<svg size="24" viewBox="0 0 512 512"><path d="M272.066 512h-32.133c-25.989 0-47.134-21.144-47.134-47.133v-10.871a206.698 206.698 0 0 1-32.097-13.323l-7.704 7.704c-18.659 18.682-48.548 18.134-66.665-.007l-22.711-22.71c-18.149-18.129-18.671-48.008.006-66.665l7.698-7.698A206.714 206.714 0 0 1 58.003 319.2h-10.87C21.145 319.2 0 298.056 0 272.067v-32.134C0 213.944 21.145 192.8 47.134 192.8h10.87a206.755 206.755 0 0 1 13.323-32.097L63.623 153c-18.666-18.646-18.151-48.528.006-66.665l22.713-22.712c18.159-18.184 48.041-18.638 66.664.006l7.697 7.697A206.893 206.893 0 0 1 192.8 58.003v-10.87C192.8 21.144 213.944 0 239.934 0h32.133C298.056 0 319.2 21.144 319.2 47.133v10.871a206.698 206.698 0 0 1 32.097 13.323l7.704-7.704c18.659-18.682 48.548-18.134 66.665.007l22.711 22.71c18.149 18.129 18.671 48.008-.006 66.665l-7.698 7.698a206.714 206.714 0 0 1 13.323 32.097h10.87c25.989 0 47.134 21.144 47.134 47.133v32.134c0 25.989-21.145 47.133-47.134 47.133h-10.87a206.755 206.755 0 0 1-13.323 32.097l7.704 7.704c18.666 18.646 18.151 48.528-.006 66.665l-22.713 22.712c-18.159 18.184-48.041 18.638-66.664-.006l-7.697-7.697a206.893 206.893 0 0 1-32.097 13.323v10.871c0 25.987-21.144 47.131-47.134 47.131zM165.717 409.17a176.812 176.812 0 0 0 45.831 19.025 14.999 14.999 0 0 1 11.252 14.524v22.148c0 9.447 7.687 17.133 17.134 17.133h32.133c9.447 0 17.134-7.686 17.134-17.133v-22.148a14.999 14.999 0 0 1 11.252-14.524 176.812 176.812 0 0 0 45.831-19.025 15 15 0 0 1 18.243 2.305l15.688 15.689c6.764 6.772 17.626 6.615 24.224.007l22.727-22.726c6.582-6.574 6.802-17.438.006-24.225l-15.695-15.695a15 15 0 0 1-2.305-18.242 176.78 176.78 0 0 0 19.024-45.831 15 15 0 0 1 14.524-11.251h22.147c9.447 0 17.134-7.686 17.134-17.133v-32.134c0-9.447-7.687-17.133-17.134-17.133H442.72a15 15 0 0 1-14.524-11.251 176.815 176.815 0 0 0-19.024-45.831 15 15 0 0 1 2.305-18.242l15.689-15.689c6.782-6.774 6.605-17.634.006-24.225l-22.725-22.725c-6.587-6.596-17.451-6.789-24.225-.006l-15.694 15.695a15 15 0 0 1-18.243 2.305 176.812 176.812 0 0 0-45.831-19.025 14.999 14.999 0 0 1-11.252-14.524v-22.15c0-9.447-7.687-17.133-17.134-17.133h-32.133c-9.447 0-17.134 7.686-17.134 17.133v22.148a14.999 14.999 0 0 1-11.252 14.524 176.812 176.812 0 0 0-45.831 19.025 15.002 15.002 0 0 1-18.243-2.305l-15.688-15.689c-6.764-6.772-17.627-6.615-24.224-.007l-22.727 22.726c-6.582 6.574-6.802 17.437-.006 24.225l15.695 15.695a15 15 0 0 1 2.305 18.242 176.78 176.78 0 0 0-19.024 45.831 15 15 0 0 1-14.524 11.251H47.134C37.687 222.8 30 230.486 30 239.933v32.134c0 9.447 7.687 17.133 17.134 17.133h22.147a15 15 0 0 1 14.524 11.251 176.815 176.815 0 0 0 19.024 45.831 15 15 0 0 1-2.305 18.242l-15.689 15.689c-6.782 6.774-6.605 17.634-.006 24.225l22.725 22.725c6.587 6.596 17.451 6.789 24.225.006l15.694-15.695c3.568-3.567 10.991-6.594 18.244-2.304z"/><path d="M256 367.4c-61.427 0-111.4-49.974-111.4-111.4S194.573 144.6 256 144.6 367.4 194.574 367.4 256 317.427 367.4 256 367.4zm0-192.8c-44.885 0-81.4 36.516-81.4 81.4s36.516 81.4 81.4 81.4 81.4-36.516 81.4-81.4-36.515-81.4-81.4-81.4z"/></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('Configurations', 'jitsi-meet-wp'), __('Width, height, recording etc...', 'jitsi-meet-wp')),
                'audio' 	    => sprintf('<svg size="24" viewBox="0 0 493.3 493.3"><path d="M384.1 372.9c-8.3 0-15 6.7-15 15v66c0 7.3-7.9 11.8-14.2 8.1 -1.6-1-125.1-74.8-180.9-108.2 0-9.5 0-203.4 0-214.2 55.9-33.4 179.3-107.2 180.9-108.2 6.2-3.7 14.2 0.7 14.2 8.1v73.3c0 8.3 6.7 15 15 15 8.3 0 15-6.7 15-15v-73.3c0-30.6-33.3-49.5-59.6-33.8l-184.7 110.4H52.9c-24.4 0-44.3 19.9-44.3 44.3v172.6c0 24.4 19.9 44.3 44.3 44.3h102l184.7 110.4c26.3 15.7 59.6-3.2 59.6-33.8v-66C399.1 379.6 392.4 372.9 384.1 372.9zM144 347.3h-91.1c-7.9 0-14.3-6.4-14.3-14.3v-172.6c0-7.9 6.4-14.3 14.3-14.3h91.1V347.3z"/><path d="M469.7 231.7h-17.5c-1.8-8.1-5-15.7-9.3-22.5 0 0 0 0 0 0l12.4-12.4c5.9-5.9 5.9-15.4 0-21.2 -5.9-5.9-15.4-5.9-21.2 0l-12.4 12.4c0 0 0 0 0 0 -6.8-4.3-14.3-7.5-22.4-9.3 0 0 0 0 0 0v-17.5c0-8.3-6.7-15-15-15s-15 6.7-15 15v17.5c-8.1 1.8-15.7 5-22.5 9.3l-12.4-12.4c-5.9-5.9-15.4-5.9-21.2 0 -5.9 5.9-5.9 15.4 0 21.2l12.4 12.4c-4.3 6.8-7.5 14.4-9.3 22.5h-17.5c-8.3 0-15 6.7-15 15s6.7 15 15 15h17.5c1.8 8.1 5 15.7 9.3 22.5l-12.4 12.4c-5.9 5.9-5.9 15.4 0 21.2 5.9 5.9 15.4 5.9 21.2 0l12.4-12.4c6.8 4.3 14.3 7.6 22.5 9.3v17.5c0 8.3 6.7 15 15 15s15-6.7 15-15v-17.5c0 0 0 0 0 0 8.1-1.8 15.7-5 22.5-9.3 0 0 0 0 0 0l12.4 12.4c5.9 5.9 15.4 5.9 21.2 0 5.9-5.9 5.9-15.4 0-21.2l-12.4-12.4c0 0 0 0 0 0 4.3-6.8 7.6-14.4 9.3-22.5h17.5c8.3 0 15-6.7 15-15S477.9 231.7 469.7 231.7zM423.8 246.7c0 21.8-17.8 39.5-39.6 39.6 0 0 0 0 0 0 0 0 0 0 0 0 -21.8 0-39.6-17.8-39.6-39.6s17.7-39.6 39.6-39.6c0 0 0 0 0 0 0 0 0 0 0 0 21.8 0 39.6 17.8 39.6 39.6 0 0 0 0 0 0.1S423.8 246.7 423.8 246.7z"/><circle cx="383.7" cy="246.7" r="18.6"/></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('Audio Settings', 'jitsi-meet-wp'), __('Initial audio configurations...', 'jitsi-meet-wp')),
                'video' 	    => sprintf('<svg size="24" viewBox="0 0 512 512"><path d="m467 18.3h-422c-24.8 0-45 20.2-45 45v318.9c0 24.8 20.2 45 45 45h196v36.6h-51.8c-8.3 0-15 6.7-15 15s6.7 15 15 15h133.6c8.3 0 15-6.7 15-15s-6.7-15-15-15h-51.8v-36.6h196c24.8 0 45-20.2 45-45v-318.9c0-24.8-20.2-45-45-45zm0 378.9h-422c-8.3 0-15-6.7-15-15v-58.6h452v58.6c0 8.3-6.7 15-15 15zm-422-348.9h422c8.3 0 15 6.7 15 15v230.3h-452v-230.3c0-8.3 6.7-15 15-15z"/><path d="m161.1 205.2c1.5 4.6 3.4 9.1 5.6 13.4-3.3 7.5-1.9 16.7 4.3 22.8l17.4 17.4c6.2 6.2 15.3 7.6 22.8 4.3 4.3 2.2 8.8 4 13.4 5.6 3 7.7 10.4 13.1 19.2 13.1h24.6c8.7 0 16.2-5.4 19.2-13.1 4.6-1.5 9.1-3.4 13.4-5.6 7.5 3.3 16.7 1.9 22.8-4.3l17.4-17.4c6.2-6.2 7.6-15.3 4.3-22.8 2.2-4.3 4-8.8 5.6-13.4 7.7-3 13.1-10.4 13.1-19.2v-24.6c0-8.7-5.4-16.2-13.1-19.2-1.5-4.6-3.4-9.1-5.6-13.4 3.3-7.5 1.9-16.7-4.3-22.8l-17.4-17.4c-6.2-6.2-15.3-7.6-22.8-4.3-4.3-2.2-8.8-4-13.4-5.6-3-7.7-10.4-13.1-19.2-13.1h-24.6c-8.7 0-16.2 5.4-19.2 13.1-4.6 1.5-9.1 3.4-13.4 5.6-7.5-3.3-16.7-1.9-22.8 4.3l-17.4 17.4c-6.2 6.2-7.6 15.3-4.3 22.8-2.2 4.3-4 8.8-5.6 13.4-7.7 3-13.1 10.4-13.1 19.2v24.6c0 8.7 5.4 16.2 13.1 19.2zm16.9-36.6c5-2.6 8.9-7.2 10.4-12.9 1.6-5.9 3.9-11.6 7-16.9 3-5.1 3.5-11.1 1.8-16.5l7.3-7.3c5.4 1.7 11.4 1.2 16.5-1.8 5.3-3.1 11-5.4 16.9-7 5.7-1.5 10.3-5.4 12.9-10.4h10.3c2.6 5 7.2 8.9 12.9 10.4 5.9 1.6 11.6 3.9 16.9 7 5.1 3 11.1 3.5 16.5 1.8l7.3 7.3c-1.7 5.4-1.2 11.4 1.8 16.5 3.1 5.3 5.4 11 7 16.9 1.5 5.7 5.4 10.3 10.4 12.9v10.3c-5 2.6-8.9 7.2-10.4 12.9-1.6 5.9-3.9 11.6-7 16.9-3 5.1-3.5 11.1-1.8 16.5l-7.3 7.3c-5.4-1.7-11.4-1.2-16.5 1.8-5.3 3.1-11 5.4-16.9 7-5.7 1.5-10.3 5.4-12.9 10.4h-10.3c-2.6-5-7.2-8.9-12.9-10.4-5.9-1.6-11.6-3.9-16.9-7-5.1-3-11.1-3.5-16.5-1.8l-7.3-7.3c1.7-5.4 1.2-11.4-1.8-16.5-3.1-5.3-5.4-11-7-16.9-1.5-5.7-5.4-10.3-10.4-12.9z"/><path d="m256 224.6c28 0 50.8-22.8 50.8-50.8s-22.8-50.8-50.8-50.8-50.8 22.8-50.8 50.8 22.8 50.8 50.8 50.8zm0-71.6c11.5 0 20.8 9.3 20.8 20.8s-9.3 20.8-20.8 20.8-20.8-9.3-20.8-20.8 9.3-20.8 20.8-20.8z"/><path d="m278.4 352.6h-44.8c-8.3 0-15 6.7-15 15s6.7 15 15 15h44.8c8.3 0 15-6.7 15-15s-6.7-15-15-15z"/></svg><label><span class="jitsi-tab-title">%1$s</span><span class="jitsi-tab-desc">%2$s</span></label>', __('Video Settings', 'jitsi-meet-wp'), __('Initial video configurations...', 'jitsi-meet-wp'))
            )
            ?>
			<div class="jitsi-setting-tab-links">
				<?php
                if ($link == 'jitsi-meet') {
                    foreach ($arroftab as $key => $value) {
                        if ($key == 'jitsi-meet') {
                            printf('<a class="jitsi-tab-link active" href="%1$s">%2$s</a>', admin_url() . 'admin.php?page=' . $key, $value);
                        } else {
                            printf('<a class="jitsi-tab-link" href="%1$s">%2$s</a>', admin_url() . 'admin.php?page=jitsi-pro-settings#' . $key, $value);
                        }
                    }
                } else {
                    foreach ($arroftab as $key => $value) {
                        if ($key == 'jitsi-meet') {
                            printf('<a class="jitsi-tab-link" href="%1$s">%2$s</a>', admin_url() . 'admin.php?page=' . $key, $value);
                        } else {
                            printf('<a class="jitsi-tab-link" href="%1$s">%2$s</a>', '#' . $key, $value);
                        }
                    }
                } ?>
			</div>
			<?php
        }

        public function jitsi_pro_preview_gen()
        {
            $app_id = get_option('jitsi_opt_app_id', '');
            $api_key = get_option('jitsi_opt_api_key', '');
            $private_key = get_option('jitsi_opt_private_key', '');
            $avatar = get_option('jitsi_opt_user_avatar', JITSI_MEET_WP_URL.'/assets/img/avatar.png');
    
            $prev_class = 'meeting-ui-preview preview-success';
            $prev_msg = ''; ?>
			<div id="meeting-ui-preview" class="<?php echo esc_attr($prev_class); ?>">
				<div class="jitsi-preview-loader">
					<svg fill="none" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" height="40px" width="40px" class="jitsi-preview-loading"><circle r="8.333333333333334" cx="10" cy="10" fill="none" stroke="#F0F3F7" stroke-width="1.6666666666666667"></circle><circle r="8.333333333333334" cx="10" cy="10" fill="none" stroke="#2087e1" stroke-width="1.6666666666666667" stroke-linecap="round" stroke-dasharray="26.179938779914945"></circle></svg>
				</div>
				<div class="jitsi-preview-message"><?php echo $prev_msg; ?></div>
				<div class="jitsi-preview-people-mock">
					<?php
                    for ($i=1;$i<9;$i++) {
                        if ($i == 4) {
                            echo '<div><div class="jitsi-pro-admin-avatar">';
                            echo '<div class="jitsi-icon icon-gsm-bars"><svg height="4" width="4" fill="#ffffff" viewBox="0 0 32 32"><path d="M2 24h4a2 2 0 012 2v4a2 2 0 01-2 2H2a2 2 0 01-2-2v-4a2 2 0 012-2zm12-12h4a2 2 0 012 2v16a2 2 0 01-2 2h-4a2 2 0 01-2-2V14a2 2 0 012-2zM26 0h4a2 2 0 012 2v28a2 2 0 01-2 2h-4a2 2 0 01-2-2V2a2 2 0 012-2z"></path></svg></div>';
                            echo '<div class="jitsi-pro-admin-avatar-thumb" style="background-image: url('.JITSI_MEET_WP_URL.'/assets/img/avatar.png'.')"></div>';
                            echo '</div></div>';
                        } else {
                            echo '<div><div style="background-image: url('.JITSI_MEET_WP_URL.'/assets/img/0'.$i.'.png)"></div></div>';
                        }
                    } ?>
				</div>
			</div>
			<?php
        }

        public function jitsi_pro_offer()
        {

			$request = wp_remote_get( esc_url('https://wppool.dev/wp-json/wppool/plugin_offers') );
			
			function load_request($response) {
				try {
					$json = json_decode( $response['body'] );
				} catch ( Exception $ex ) {
					$json = null;
				}
				return $json;
			}

			$response = load_request($request);

			$countdown_time = get_transient('jitsi_promo_time');

			if (!$countdown_time) {
				if($response->counter_time){
					$date = date('Y-m-d-H-i', strtotime($response->counter_time));
				} else {
					$date = date('Y-m-d-H-i', strtotime('+ 14 hours'));
				}
				$date_parts = explode('-', $date);
				$countdown_time = [
					'year'   => $date_parts[0],
					'month'  => $date_parts[1],
					'day'    => $date_parts[2],
					'hour'   => $date_parts[3],
					'minute' => $date_parts[4],
				];
				set_transient('jitsi_promo_time', $countdown_time, 14 * HOUR_IN_SECONDS);
			}
			?>
			<div class="jitsi-promo hidden <?php if(false == ($jitsi_select_api = get_option('jitsi_opt_select_api_free', false))) {echo 'jitsi-promo-fullpage'; }?>">
				<div class="jitsi-promo-inner">
					<span class="close-promo">&times;</span>
					<img src="<?php echo JITSI_MEET_WP_URL . '/assets/img/gift-box.svg'; ?>" class="promo-img">
					<h3 class="promo-title"><?php esc_html_e('Unlock all the features', 'jitsi-meet-wp'); ?></h3>
					<?php 
					if(isset($response->jitsi_meet->discount_image) && $response->jitsi_meet->discount_image){
						printf('<img class="discount" src="%1$s" alt="Special Offer"/>', esc_url($response->jitsi_meet->discount_image));
					} else {
						?>
						<div class="discount"><span class="discount-special"><?php esc_html_e('SPECIAL', 'jitsi-meet-wp'); ?></span><span class="discount-text"><?php esc_html_e('50% OFF', 'jitsi-meet-wp'); ?></span></div>
						<?php 
					}
					?><?php
                    if (! empty($countdown_time)) {
                        echo '<div class="simple_timer"></div>';
                    } ?>
					<a href="https://go.wppool.dev/JbH" target="_blank"><?php esc_html_e('Get Premium', 'jitsi-meet-wp'); ?></a>
				</div>
			</div>
			<style>
				.syotimer {
					text-align: center;
					padding: 0 0 10px;
				}

				.syotimer-cell {
					display: inline-block;
					margin: 0 14px;

					width: 50px;
					background: url(<?php echo JITSI_MEET_WP_ASSETS.'/img/timer.svg'; ?>) no-repeat 0 0;
					background-size: contain;
				}

				.syotimer-cell__value {
					font-size: 28px;
					color: #fff;

					height: 54px;
					line-height: 54px;

					margin: 0 0 5px;
				}

				.syotimer-cell__unit {
					font-family: Arial, serif;
					font-size: 12px;
					text-transform: uppercase;
					color: #fff;
				}
			</style>
			<script>
				(function ($) {
					$(document).ready(function () {

						//show popup
						$(document).on('click', '.jitsi-setting-tabs-wrapper .disabled', function (e) {
							e.preventDefault();

							$('.jitsi-promo').removeClass('hidden');

							$('html, body').animate({
								scrollTop: $('.jitsi-promo').offset().top
							}, 'slow');

						});

						//close promo
						$(document).on('click', '.close-promo', function () {
							$('.jitsi-promo').addClass('hidden');
						});

						//close promo
						$(document).on('click', '.jitsi-promo', function (e) {

							if (e.target !== this) {
								return;
							}

							$(this).addClass('hidden');
						});

						<?php
                        if (! empty($countdown_time)) {
                            ?>

						if (typeof window.timer_set === 'undefined') {
							window.timer_set = $('.simple_timer').syotimer({
								year: <?php echo $countdown_time['year']; ?>,
								month: <?php echo $countdown_time['month']; ?>,
								day: <?php echo $countdown_time['day']; ?>,
								hour: <?php echo $countdown_time['hour']; ?>,
								minute: <?php echo $countdown_time['minute']; ?>
							});
						}
						<?php
                        } ?>

					})
				})(jQuery);
			</script>
			<?php
        }

		public function jitsi_pro_manu_page_welcome_output(){
			?>
			<div class="jitsi-setting-tabs-wrapper active" id="jitsi-setting-tab-apis">
				<div class="jitsi-meet-welcome" id="jitsi-meet-welcome">
					<div class="jitsi-meet-welcome-content">
						<svg xmlns="http://www.w3.org/2000/svg" width="312" height="56" viewBox="0 0 156 28" fill="none">
							<g clip-path="url(#clip0_1262_13)">
							<path fill-rule="evenodd" clip-rule="evenodd" d="M34.4757 22.2613V17.4941L43.0323 23.606C43.5361 23.9658 44.1987 24.0139 44.7491 23.7306C45.2996 23.4474 45.6455 22.8802 45.6455 22.2612V5.73487C45.6455 5.11582 45.2996 4.54868 44.7491 4.26541C44.1987 3.98214 43.5361 4.03025 43.0323 4.39007L34.4757 10.502V5.73499C34.4757 2.81736 31.8784 0.7771 29.0998 0.7771H8.62239C5.84387 0.7771 3.24658 2.81736 3.24658 5.73499V22.2613C3.24658 25.1789 5.84387 27.2192 8.62239 27.2192H29.0998C31.8784 27.2192 34.4757 25.1789 34.4757 22.2613ZM20.3316 18.3758C17.8232 17.0905 15.7668 15.0431 14.4904 12.5347L16.4404 10.5846C16.6886 10.3364 16.7596 9.99076 16.6621 9.68054C16.3341 8.68779 16.1568 7.62416 16.1568 6.51622C16.1568 6.02871 15.758 5.62985 15.2704 5.62985H12.1681C11.6807 5.62985 11.2818 6.02871 11.2818 6.51622C11.2818 14.8392 18.027 21.5845 26.35 21.5845C26.8375 21.5845 27.2364 21.1856 27.2364 20.6981V17.6047C27.2364 17.1172 26.8375 16.7183 26.35 16.7183C25.2509 16.7183 24.1784 16.541 23.1857 16.2131C22.8755 16.1067 22.5209 16.1865 22.2816 16.4258L20.3316 18.3758ZM25.8625 5.62099L26.4918 6.24144L20.8989 11.8344H24.5773V12.7208H19.2591V7.40259H20.1455V11.2051L25.8625 5.62099Z" fill="#407BFF"/>
							<path d="M63.8221 8.05792V17.2932C63.8221 17.8697 63.7238 18.3909 63.5277 18.8569C63.3438 19.323 63.0742 19.7216 62.7183 20.0527C62.3751 20.3839 61.9519 20.6414 61.4489 20.8254C60.9459 21.0094 60.3818 21.1014 59.7563 21.1014C58.5666 21.1014 57.6407 20.7948 56.9784 20.1815C56.3161 19.556 55.893 18.7282 55.709 17.6979L57.9534 17.238C58.0638 17.7899 58.26 18.2192 58.5421 18.5258C58.8365 18.8201 59.2351 18.9673 59.7379 18.9673C60.2162 18.9673 60.6087 18.8201 60.9154 18.5258C61.2345 18.2192 61.3937 17.7531 61.3937 17.1276V10.0448H57.3463V8.05792H63.8221ZM66.5178 20.899V18.9489H68.2104V10.008H66.5178V8.05792H72.3497V10.008H70.6388V18.9489H72.3497V20.899H66.5178ZM80.0689 10.2104V20.899H77.6405V10.2104H73.9979V8.05792H83.7115V10.2104H80.0689ZM89.7641 21.1198C88.6603 21.1198 87.7221 20.9236 86.9494 20.5311C86.1888 20.1386 85.5328 19.6235 84.9809 18.9857L86.6182 17.4036C87.0598 17.9187 87.5502 18.3112 88.09 18.581C88.6419 18.8508 89.249 18.9857 89.9113 18.9857C90.6592 18.9857 91.2238 18.8263 91.6038 18.5074C91.9838 18.1763 92.1741 17.7347 92.1741 17.1828C92.1741 16.7535 92.0517 16.404 91.8062 16.1342C91.5607 15.8644 91.1008 15.6681 90.4264 15.5455L89.2122 15.3615C86.6487 14.9568 85.3672 13.7119 85.3672 11.6269C85.3672 11.0505 85.4713 10.5293 85.68 10.0632C85.9008 9.59712 86.2135 9.19853 86.6182 8.86739C87.023 8.53624 87.5076 8.28484 88.0716 8.11311C88.6482 7.92914 89.2979 7.83716 90.0217 7.83716C90.9904 7.83716 91.8367 7.99658 92.5605 8.31548C93.2843 8.63438 93.9034 9.10655 94.4186 9.73205L92.7628 11.2958C92.4438 10.9033 92.0574 10.5845 91.6038 10.3391C91.1502 10.0938 90.5799 9.97121 89.8929 9.97121C89.1938 9.97121 88.6666 10.1061 88.3108 10.3759C87.9675 10.6335 87.7956 11.0014 87.7956 11.4798C87.7956 11.9703 87.9365 12.3322 88.2188 12.5652C88.5011 12.7982 88.9547 12.9699 89.5802 13.0803L90.776 13.3011C92.0758 13.5341 93.0325 13.9511 93.6459 14.552C94.2714 15.1408 94.5841 15.9686 94.5841 17.0356C94.5841 17.6489 94.4737 18.2069 94.253 18.7098C94.0443 19.2003 93.7315 19.6296 93.3147 19.9976C92.91 20.3532 92.407 20.6292 91.8062 20.8254C91.2175 21.0216 90.5368 21.1198 89.7641 21.1198ZM96.7722 20.899V18.9489H98.4647V10.008H96.7722V8.05792H102.604V10.008H100.893V18.9489H102.604V20.899H96.7722ZM115.068 11.6821H114.994L114.001 13.7242L111.37 18.581L108.739 13.7242L107.746 11.6821H107.672V20.899H105.373V8.05792H108.114L111.407 14.3313H111.481L114.737 8.05792H117.368V20.899H115.068V11.6821ZM120.68 20.899V8.05792H129.142V10.2104H123.108V13.3195H128.443V15.4719H123.108V18.7466H129.142V20.899H120.68ZM131.998 20.899V8.05792H140.46V10.2104H134.426V13.3195H139.761V15.4719H134.426V18.7466H140.46V20.899H131.998ZM148.357 10.2104V20.899H145.929V10.2104H142.286V8.05792H152V10.2104H148.357Z" fill="#407BFF"/>
							</g>
							<defs>
							<clipPath id="clip0_1262_13">
							<rect width="156" height="27.6" fill="white" transform="translate(0 0.199951)"/>
							</clipPath>
							</defs>
						</svg>
				<form method="post" action="<?php echo admin_url( 'admin.php?page=jitsi-pro-settings' ); ?>" class="jitsi-pro-option-form jitsi-welcome-option-form" id="jaasOptionFormApi">
					<?php 
					printf(
						'<p class="wc-title">%1$s</p><p class="wc-text">%2$s</p>',
						__('Welcome to Jitsi Meet WP', 'jitsi-pro'),
						__('Select for which kind of api you want to use with our plugin and give credential accordingly.', 'jitsi-pro')
					);
					?>
					<div class="jitsi-setting-tab active">
					<?php
						settings_fields('jitsi-pro-api');
						do_settings_sections('jitsi-pro-api');
						echo '<p class="submit">';
						echo '<a class="button button-secondary" href="'.admin_url( 'admin.php?page=jitsi-pro-settings' ).'">'.__('Skip', 'jitsi-pro').'</a>';
						submit_button('Continue', 'primary', 'submit', false); 
						echo '</p>';
					?>
					</div>
					<div class="jitsi-welcome-video">
						<p class="jitsi-welcome-video-title"><?php _e('How to select Jitsi Meet server?', 'jitsi-pro'); ?></p>
						<iframe style="max-width: 100%" width="778" height="438" src="https://www.youtube.com/embed/FGu8GR_0_Ks" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
					</div>
				</form>
				</div>
				<?php $this->jitsi_pro_offer(); ?>
				</div>
			</div>
			<?php 
		}

        public function jitsi_pro_manu_page_apis_output()
        {
            ?>
			<div class="wrapv jitsi-admin-wrap jitsi-wrap">
				<?php settings_errors(); ?>
				<h3 class="title">
					<svg xmlns="http://www.w3.org/2000/svg" height="40" viewBox="0 0 49 28" fill="none">
						<path fill-rule="evenodd" clip-rule="evenodd" d="M34.4757 22.0614V17.2941L43.0323 23.4061C43.5361 23.7659 44.1987 23.814 44.7491 23.5307C45.2996 23.2474 45.6455 22.6803 45.6455 22.0612V5.53492C45.6455 4.91587 45.2996 4.34873 44.7491 4.06545C44.1987 3.78219 43.5361 3.8303 43.0323 4.19012L34.4757 10.3021V5.53504C34.4757 2.61741 31.8784 0.577148 29.0998 0.577148H8.62239C5.84387 0.577148 3.24658 2.61741 3.24658 5.53504V22.0614C3.24658 24.979 5.84387 27.0193 8.62239 27.0193H29.0998C31.8784 27.0193 34.4757 24.979 34.4757 22.0614ZM20.3316 18.1759C17.8232 16.8906 15.7668 14.8431 14.4904 12.3347L16.4404 10.3847C16.6886 10.1365 16.7596 9.79081 16.6621 9.48059C16.3341 8.48784 16.1568 7.42421 16.1568 6.31627C16.1568 5.82876 15.758 5.4299 15.2704 5.4299H12.1681C11.6807 5.4299 11.2818 5.82876 11.2818 6.31627C11.2818 14.6393 18.027 21.3845 26.35 21.3845C26.8375 21.3845 27.2364 20.9856 27.2364 20.4981V17.4047C27.2364 16.9172 26.8375 16.5183 26.35 16.5183C25.2509 16.5183 24.1784 16.341 23.1857 16.0131C22.8755 15.9068 22.5209 15.9865 22.2816 16.2258L20.3316 18.1759ZM25.8625 5.42103L26.4918 6.04149L20.8989 11.6345H24.5773V12.5209H19.2591V7.20264H20.1455V11.0051L25.8625 5.42103Z" fill="#407BFF"/>
					</svg>
					<span><?php echo esc_html__('Webinar and Video Conference with Jitsi Meet', 'jitsi-meet-wp') ?></span>
				</h3>
				<div class="option-form-field-wrap">
					<?php $this->jitsi_pro_menu_page_tab_link(); ?>
					<div class="jitsi-setting-tabs">
						<div class="jitsi-setting-tabs-wrapper active" id="jitsi-setting-tab-apis">
							<form method="post" action="options.php#apis" class="jitsi-pro-option-form jitsi-welcome-option-form" id="jaasOptionFormApi">
                                <div class="jitsi-setting-tab active">
                                <?php
                                    settings_fields('jitsi-pro-api');
									do_settings_sections('jitsi-pro-api');
									submit_button('Save Changes'); 
								?>
                                </div>
                            </form>
							<?php $this->jitsi_pro_preview_gen(); ?>
						</div>
						<div class="jitsi-setting-tabs-wrapper" id="jitsi-setting-tab-admin">
							<form method="post" action="options.php#admin" class="jitsi-pro-option-form" id="jaasOptionFormAdmin">
							    <div class="jitsi-setting-tab active">
                                <?php
                                    settings_fields('jitsi-pro-admin');
            do_settings_sections('jitsi-pro-admin');
            submit_button('Save Changes'); ?>
                                </div>
                            </form>
							<?php $this->jitsi_pro_preview_gen(); ?>
						</div>
						<div class="jitsi-setting-tabs-wrapper" id="jitsi-setting-tab-config">
							<form method="post" action="options.php#config" class="jitsi-pro-option-form" id="jaasOptionFormConfig">
                                <div class="jitsi-setting-tab active">
                                <?php
                                    settings_fields('jitsi-pro-config');
            do_settings_sections('jitsi-pro-config');
            submit_button('Save Changes'); ?>
                                </div>
                            </form>
							<?php $this->jitsi_pro_preview_gen(); ?>
						</div>
						<div class="jitsi-setting-tabs-wrapper" id="jitsi-setting-tab-audio">
							<form method="post" action="options.php#audio" class="jitsi-pro-option-form" id="jaasOptionFormAudio">
							<div class="jitsi-setting-tab active">
                            <?php
                                    settings_fields('jitsi-pro-audio');
            do_settings_sections('jitsi-pro-audio');
            submit_button('Save Changes'); ?>
                            </div></form>
							<?php $this->jitsi_pro_preview_gen(); ?>
						</div>
						<div class="jitsi-setting-tabs-wrapper" id="jitsi-setting-tab-video">
							<form method="post" action="options.php#video" class="jitsi-pro-option-form" id="jaasOptionFormVideo">
							    <div class="jitsi-setting-tab active">
                                <?php
                                    settings_fields('jitsi-pro-video');
            do_settings_sections('jitsi-pro-video');
            submit_button('Save Changes'); ?>
                                </div>
                            </form>
							<?php $this->jitsi_pro_preview_gen(); ?>
						</div>
						<?php $this->jitsi_pro_offer(); ?>
					</div>
				</div>
			</div>
			<?php
        }

		/**
		 * @return Jitsi_Meet_WP_Admin|null
		 */
		public static function instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}

}

Jitsi_Meet_WP_Admin::instance();
